# RANSAC and PROSAC algorithms in python

This package provides an implementation of the RANSAC and PROSAC algorithms in Python.
This implementation draws inspiration from [prosac.c](http://devernay.free.fr/vision/src/prosac.c).

Explanation of the PROSAC algorithm can be found
at: [https://willguimont.github.io/cs/2019/12/26/prosac-algorithm.html](https://willguimont.github.io/cs/2019/12/26/prosac-algorithm.html)

## Installation

```bash
pip install prosac
```

## Usage

See the `examples` directory for examples of usage.

## Installation from source

Add the following line in your `requirements.txt`:

```
git+https://github.com/willGuimont/PROSAC
```
